@@ -24,7 +24,7 @@ int32_t tosent = 0;
 
 int32_t smtp_enum_cmd = VRFY;
 
-int32_t start_smtp_enum(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE * fp) {
+int32_t start_smtp_enum(int32_t s, char *ip, int32_t port, unsigned char options, char *miscptr, FILE *fp) {
   char *empty = "";
   char *login, *pass, buffer[500];
 
@@ -55,7 +55,7 @@ int32_t start_smtp_enum(int32_t s, char *ip, int32_t port, unsigned char options
       return (1);
     if (debug)
       hydra_report(stderr, "DEBUG S: %s", buf);
-    /* good return values are something like 25x */
+      /* good return values are something like 25x */
 #ifdef HAVE_PCRE
     if (hydra_string_match(buf, "^25\\d\\s")) {
 #else
@@ -103,7 +103,7 @@ int32_t start_smtp_enum(int32_t s, char *ip, int32_t port, unsigned char options
     return (1);
   if (debug)
     hydra_report(stderr, "DEBUG S: %s", buf);
-  /* good return values are something like 25x */
+    /* good return values are something like 25x */
 #ifdef HAVE_PCRE
   if (hydra_string_match(buf, "^25\\d\\s")) {
 #else
@@ -119,21 +119,25 @@ int32_t start_smtp_enum(int32_t s, char *ip, int32_t port, unsigned char options
   err = strstr(buf, "Error");
   if (err || tosent || strncmp(buf, "50", 2) == 0) {
     // we should report command not identified by the server
-    //502 5.5.2 Error: command not recognized
-//#ifdef HAVE_PCRE
-//    if ((debug || hydra_string_match(buf, "\\scommand\\snot\\srecognized")) && err) {
-//#else
-//    if ((debug || strstr(buf, "command") != NULL) && err) {
-//#endif
-//      hydra_report(stderr, "Server %s", err);
-//    }
+    // 502 5.5.2 Error: command not recognized
+    //#ifdef HAVE_PCRE
+    //    if ((debug || hydra_string_match(buf,
+    //    "\\scommand\\snot\\srecognized")) && err) {
+    //#else
+    //    if ((debug || strstr(buf, "command") != NULL) && err) {
+    //#endif
+    //      hydra_report(stderr, "Server %s", err);
+    //    }
     if (strncmp(buf, "500 ", 4) == 0) {
-      hydra_report(stderr, "[ERROR] command is disabled on the server (choose different method): %s", buf);
+      hydra_report(stderr,
+                   "[ERROR] command is disabled on the server (choose "
+                   "different method): %s",
+                   buf);
       free(buf);
       return 3;
     }
     memset(buffer, 0, sizeof(buffer));
-    //503 5.5.1 Error: nested MAIL command
+    // 503 5.5.1 Error: nested MAIL command
     strncpy(buffer, "RSET\r\n", sizeof(buffer));
     free(buf);
     if (hydra_send(s, buffer, strlen(buffer), 0) < 0)
@@ -150,7 +154,7 @@ int32_t start_smtp_enum(int32_t s, char *ip, int32_t port, unsigned char options
   return 2;
 }
 
-void service_smtp_enum(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+void service_smtp_enum(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   int32_t run = 1, next_run = 1, sock = -1, i = 0;
   int32_t myport = PORT_SMTP, mysslport = PORT_SMTP_SSL;
   char *buffer = "HELO hydra\r\n";
@@ -160,7 +164,7 @@ void service_smtp_enum(char *ip, int32_t sp, unsigned char options, char *miscpt
     return;
   while (1) {
     switch (run) {
-    case 1:                    /* connect and service init function */
+    case 1: /* connect and service init function */
       if (sock >= 0)
         sock = hydra_disconnect(sock);
       if ((options & OPTION_SSL) == 0) {
@@ -175,7 +179,7 @@ void service_smtp_enum(char *ip, int32_t sp, unsigned char options, char *miscpt
         port = mysslport;
       }
       if (sock < 0) {
-        hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t) getpid());
+        hydra_report(stderr, "[ERROR] Child with pid %d terminating, can not connect\n", (int32_t)getpid());
         hydra_child_exit(1);
       }
       /* receive initial header */
@@ -185,17 +189,17 @@ void service_smtp_enum(char *ip, int32_t sp, unsigned char options, char *miscpt
         hydra_report(stderr, "Warning: SMTP does not allow connecting: %s\n", buf);
         hydra_child_exit(2);
       }
-//      while (strstr(buf, "220 ") == NULL) {
-//        free(buf);
-//        buf = hydra_receive_line(sock);
-//      }
+      //      while (strstr(buf, "220 ") == NULL) {
+      //        free(buf);
+      //        buf = hydra_receive_line(sock);
+      //      }
 
-//      if (buf[0] != '2') {
+      //      if (buf[0] != '2') {
       if (hydra_send(sock, buffer, strlen(buffer), 0) < 0) {
         free(buf);
         hydra_child_exit(2);
       }
-//      }
+      //      }
 
       free(buf);
       if ((buf = hydra_receive_line(sock)) == NULL)
@@ -207,7 +211,7 @@ void service_smtp_enum(char *ip, int32_t sp, unsigned char options, char *miscpt
 
       if ((miscptr != NULL) && (strlen(miscptr) > 0)) {
         for (i = 0; i < strlen(miscptr); i++)
-          miscptr[i] = (char) toupper((int32_t) miscptr[i]);
+          miscptr[i] = (char)toupper((int32_t)miscptr[i]);
 
         if (strncmp(miscptr, "EXPN", 4) == 0)
           smtp_enum_cmd = EXPN;
@@ -232,10 +236,10 @@ void service_smtp_enum(char *ip, int32_t sp, unsigned char options, char *miscpt
       free(buf);
       next_run = 2;
       break;
-    case 2:                    /* run the cracking function */
+    case 2: /* run the cracking function */
       next_run = start_smtp_enum(sock, ip, port, options, miscptr, fp);
       break;
-    case 3:                    /* clean exit */
+    case 3: /* clean exit */
       if (sock >= 0) {
         sock = hydra_disconnect(sock);
       }
@@ -249,13 +253,13 @@ void service_smtp_enum(char *ip, int32_t sp, unsigned char options, char *miscpt
   }
 }
 
-int32_t service_smtp_enum_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE * fp, int32_t port, char *hostname) {
+int32_t service_smtp_enum_init(char *ip, int32_t sp, unsigned char options, char *miscptr, FILE *fp, int32_t port, char *hostname) {
   // called before the childrens are forked off, so this is the function
   // which should be filled if initial connections and service setup has to be
   // performed once only.
   //
   // fill if needed.
-  // 
+  //
   // return codes:
   //   0 all OK
   //   -1  error, hydra will exit, so print a good error message here
@@ -263,9 +267,11 @@ int32_t service_smtp_enum_init(char *ip, int32_t sp, unsigned char options, char
   return 0;
 }
 
-void usage_smtp_enum(const char* service) {
+void usage_smtp_enum(const char *service) {
   printf("Module smtp-enum is optionally taking one SMTP command of:\n\n"
          "VRFY (default), EXPN, RCPT (which will connect using \"root\" account)\n"
-         "login parameter is used as username and password parameter as the domain name\n"
-         "For example to test if john@localhost exists on 192.168.0.1:\n" "hydra smtp-enum://192.168.0.1/vrfy -l john -p localhost\n\n");
+         "login parameter is used as username and password parameter as the "
+         "domain name\n"
+         "For example to test if john@localhost exists on 192.168.0.1:\n"
+         "hydra smtp-enum://192.168.0.1/vrfy -l john -p localhost\n\n");
 }
